==> huaweicloudsdklts-3.0.49-py2.py3-none-any.whl: huaweicloudsdklts/v2/model/__init__.py <==
# coding: utf-8

from __future__ import absolute_import

# import models into model package
from huaweicloudsdklts.v2.model.create_log_dump_obs_request import CreateLogDumpObsRequest
from huaweicloudsdklts.v2.model.create_log_dump_obs_request_body import CreateLogDumpObsRequestBody
from huaweicloudsdklts.v2.model.create_log_dump_obs_response import CreateLogDumpObsResponse
from huaweicloudsdklts.v2.model.create_log_group_params import CreateLogGroupParams
from huaweicloudsdklts.v2.model.create_log_group_request import CreateLogGroupRequest
from huaweicloudsdklts.v2.model.create_log_group_response import CreateLogGroupResponse
from huaweicloudsdklts.v2.model.create_log_stream_params import CreateLogStreamParams
from huaweicloudsdklts.v2.model.create_log_stream_request import CreateLogStreamRequest
from huaweicloudsdklts.v2.model.create_log_stream_response import CreateLogStreamResponse
from huaweicloudsdklts.v2.model.delete_log_group_request import DeleteLogGroupRequest
from huaweicloudsdklts.v2.model.delete_log_group_response import DeleteLogGroupResponse
from huaweicloudsdklts.v2.model.delete_log_stream_request import DeleteLogStreamRequest
from huaweicloudsdklts.v2.model.delete_log_stream_response import DeleteLogStreamResponse
from huaweicloudsdklts.v2.model.disable_log_collection_request import DisableLogCollectionRequest
from huaweicloudsdklts.v2.model.disable_log_collection_response import DisableLogCollectionResponse
from huaweicloudsdklts.v2.model.enable_log_collection_request import EnableLogCollectionRequest
from huaweicloudsdklts.v2.model.enable_log_collection_response import EnableLogCollectionResponse
from huaweicloudsdklts.v2.model.list_log_groups_request import ListLogGroupsRequest
from huaweicloudsdklts.v2.model.list_log_groups_response import ListLogGroupsResponse
from huaweicloudsdklts.v2.model.list_log_stream_request import ListLogStreamRequest
from huaweicloudsdklts.v2.model.list_log_stream_response import ListLogStreamResponse
from huaweicloudsdklts.v2.model.log_contents import LogContents
from huaweicloudsdklts.v2.model.log_group import LogGroup
from huaweicloudsdklts.v2.model.log_stream import LogStream
from huaweicloudsdklts.v2.model.query_lts_log_params import QueryLTSLogParams
from huaweicloudsdklts.v2.model.query_lts_struct_log_params import QueryLTSStructLogParams
from huaweicloudsdklts.v2.model.query_lts_struct_log_params_new import QueryLTSStructLogParamsNew
from huaweicloudsdklts.v2.model.struct_log_contents import StructLogContents
from huaweicloudsdklts.v2.model.update_log_contents2_request import UpdateLogContents2Request
from huaweicloudsdklts.v2.model.update_log_contents2_response import UpdateLogContents2Response
from huaweicloudsdklts.v2.model.update_log_contents3_request import UpdateLogContents3Request
from huaweicloudsdklts.v2.model.update_log_contents3_response import UpdateLogContents3Response
from huaweicloudsdklts.v2.model.update_log_contents_request import UpdateLogContentsRequest
from huaweicloudsdklts.v2.model.update_log_contents_response import UpdateLogContentsResponse
from huaweicloudsdklts.v2.model.update_log_group_params import UpdateLogGroupParams
from huaweicloudsdklts.v2.model.update_log_group_request import UpdateLogGroupRequest
from huaweicloudsdklts.v2.model.update_log_group_response import UpdateLogGroupResponse

==> huaweicloudsdklts-3.0.56-py2.py3-none-any.whl: huaweicloudsdklts/v2/model/__init__.py <==
# coding: utf-8

from __future__ import absolute_import

# import models into model package
from huaweicloudsdklts.v2.model.create_log_dump_obs_request import CreateLogDumpObsRequest
from huaweicloudsdklts.v2.model.create_log_dump_obs_request_body import CreateLogDumpObsRequestBody
from huaweicloudsdklts.v2.model.create_log_dump_obs_response import CreateLogDumpObsResponse
from huaweicloudsdklts.v2.model.create_log_group_params import CreateLogGroupParams
from huaweicloudsdklts.v2.model.create_log_group_request import CreateLogGroupRequest
from huaweicloudsdklts.v2.model.create_log_group_response import CreateLogGroupResponse
from huaweicloudsdklts.v2.model.create_log_stream_params import CreateLogStreamParams
from huaweicloudsdklts.v2.model.create_log_stream_request import CreateLogStreamRequest
from huaweicloudsdklts.v2.model.create_log_stream_response import CreateLogStreamResponse
from huaweicloudsdklts.v2.model.delete_log_group_request import DeleteLogGroupRequest
from huaweicloudsdklts.v2.model.delete_log_group_response import DeleteLogGroupResponse
from huaweicloudsdklts.v2.model.delete_log_stream_request import DeleteLogStreamRequest
from huaweicloudsdklts.v2.model.delete_log_stream_response import DeleteLogStreamResponse
from huaweicloudsdklts.v2.model.disable_log_collection_request import DisableLogCollectionRequest
from huaweicloudsdklts.v2.model.disable_log_collection_response import DisableLogCollectionResponse
from huaweicloudsdklts.v2.model.enable_log_collection_request import EnableLogCollectionRequest
from huaweicloudsdklts.v2.model.enable_log_collection_response import EnableLogCollectionResponse
from huaweicloudsdklts.v2.model.list_log_groups_request import ListLogGroupsRequest
from huaweicloudsdklts.v2.model.list_log_groups_response import ListLogGroupsResponse
from huaweicloudsdklts.v2.model.list_log_stream_request import ListLogStreamRequest
from huaweicloudsdklts.v2.model.list_log_stream_response import ListLogStreamResponse
from huaweicloudsdklts.v2.model.list_logs_request import ListLogsRequest
from huaweicloudsdklts.v2.model.list_logs_response import ListLogsResponse
from huaweicloudsdklts.v2.model.list_query_structured_logs_request import ListQueryStructuredLogsRequest
from huaweicloudsdklts.v2.model.list_query_structured_logs_response import ListQueryStructuredLogsResponse
from huaweicloudsdklts.v2.model.list_structured_logs_with_time_range_request import ListStructuredLogsWithTimeRangeRequest
from huaweicloudsdklts.v2.model.list_structured_logs_with_time_range_response import ListStructuredLogsWithTimeRangeResponse
from huaweicloudsdklts.v2.model.log_contents import LogContents
from huaweicloudsdklts.v2.model.log_group import LogGroup
from huaweicloudsdklts.v2.model.log_stream import LogStream
from huaweicloudsdklts.v2.model.query_lts_log_params import QueryLTSLogParams
from huaweicloudsdklts.v2.model.query_lts_struct_log_params import QueryLTSStructLogParams
from huaweicloudsdklts.v2.model.query_lts_struct_log_params_new import QueryLTSStructLogParamsNew
from huaweicloudsdklts.v2.model.struct_log_contents import StructLogContents
from huaweicloudsdklts.v2.model.time_range import TimeRange
from huaweicloudsdklts.v2.model.update_log_group_params import UpdateLogGroupParams
from huaweicloudsdklts.v2.model.update_log_group_request import UpdateLogGroupRequest
from huaweicloudsdklts.v2.model.update_log_group_response import UpdateLogGroupResponse
